@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.528-9-g6e471c4e
+package JSON::Schema::Modern; # git description: v0.529-3-gfbc5ef2e
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema
 # KEYWORDS: JSON Schema data validation structure specification
 
-our $VERSION = '0.529';
+our $VERSION = '0.530';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -869,7 +869,10 @@ sub FREEZE ($self, $serializer) {
 }
 
 sub THAW ($class, $serializer, $data) {
-  my %bare_attrs = delete $data->%{qw(_resource_index _vocabulary_classes _metaschema_vocabulary_classes)};
+  # sadly I can't do %bare_attrs = delete ...->%{...} until 5.28
+  my %bare_attrs;
+  @bare_attrs{qw(_resource_index _vocabulary_classes _metaschema_vocabulary_classes)}
+    = delete $data->@{qw(_resource_index _vocabulary_classes _metaschema_vocabulary_classes)};
 
   my $self = $class->new($data);
   $self->_add_resources_unsafe($bare_attrs{_resource_index}->%*);
@@ -897,7 +900,7 @@ JSON::Schema::Modern - Validate data against a schema
 
 =head1 VERSION
 
-version 0.529
+version 0.530
 
 =head1 SYNOPSIS
 
